# -*- coding: utf-8 -*-

"""
Author: Alexandra Moine-Franel
Date: March 2018
Version: 1


DOWNLOAD PDB 3D STRUCTURE FILES FROM PDB 


Usage: [Script.py] [pdb_id]
------------------------------------------------------------------
Argument:
	[file]: list of PDB IDs (txt format)

Return:
	[file]: PDB files, stored in 'PDB' folder
"""

# =============================================================================

import os
import argparse
import logging
import csv
import Bio
from Bio.PDB import PDBList

# =============================================================================

LOG = logging.getLogger("DOWNLOAD PDB 3D STRUCTURE FILES")

FOLDER = 'PDB'

# =============================================================================

def main(pdb_id):
	get_pdb_file(get_pdbID(pdb_id))
	rename_pdb_file()

	
def get_pdbID(txtfile):
	pdb_id = []
	with open(txtfile, 'rb') as pdb_txtfile:
		for line in csv.reader(pdb_txtfile):	
			pdb_id.append(line[0].upper())
	return pdb_id		


def get_pdb_file(pdbID):
	for i in pdbID:
		PDBList().retrieve_pdb_file(i, pdir = FOLDER, file_format = 'pdb')
	

def rename_pdb_file():
	working_dir = os.path.dirname(__file__)
	pdb_dir = os.path.abspath(os.path.join(working_dir, FOLDER))	
	os.chdir(pdb_dir)
	for filename in os.listdir(pdb_dir):
		os.rename(filename, filename.replace('pdb', '').replace('ent', 'pdb'))
	

def setlogger():
    LOG.setLevel(logging.INFO)
    ch = logging.StreamHandler()
    ch.setLevel(logging.INFO)
    formatter = logging.Formatter('%(asctime)s - %(name)s - %(funcName)s - %(levelname)s - %(message)s')
    ch.setFormatter(formatter)
    LOG.addHandler(ch)

# =============================================================================

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description = 
					'DOWNLOAD PDB 3D STRUCTURE FILES FROM PDB')
    parser.add_argument('pdb_id', help = 'Input [.txt file]: PDB IDs')
    options = parser.parse_args()
    setlogger()
    main(options.pdb_id)
